/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the OX Software GmbH group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2016-2020 OX Software GmbH
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.saml.spi;

import java.util.List;
import org.opensaml.xml.security.credential.Credential;


/**
 * Abstract class for {@link CredentialProvider} implementations.
 *
 * @author <a href="mailto:steffen.templin@open-xchange.com">Steffen Templin</a>
 * @since v7.6.1
 */
public abstract class AbstractCredentialProvider implements CredentialProvider {

    private final List<Credential> idpCertificateCredential;

    private final Credential signingCredential;

    private final Credential decryptionCredential;

    /**
     * Initializes a new {@link KeyStoreCredentialProvider}.
     *
     * @param idpPublicKeyCredentials The credential list containing the IDPs public keys used for validating signatures or <code>null</code>
     * @param signingPrivateKeyCredential The credential containing the SPs private key used for signing requests or <code>null</code>
     * @param decryptionPrivateKeyCredential The credential containing the private key used to decrypt encrypted data or encryption keys or <code>null</code>
     */
    protected AbstractCredentialProvider(List<Credential> idpPublicKeyCredentials, Credential signingPrivateKeyCredential, Credential decryptionPrivateKeyCredential) {
        super();
        this.idpCertificateCredential = idpPublicKeyCredentials;
        this.signingCredential = signingPrivateKeyCredential;
        this.decryptionCredential = decryptionPrivateKeyCredential;
    }
    
    @Override
    public boolean hasValidationCredential() {
        return hasValidationCredentials();
    }
    
    @Override
    public Credential getValidationCredential() {
        List<Credential> validationCredentials = getValidationCredentials();
        return validationCredentials != null && validationCredentials.isEmpty() == false ? validationCredentials.get(0) : null;
    }

    @Override
    public boolean hasValidationCredentials() {
        return idpCertificateCredential != null;
    }

    @Override
    public List<Credential> getValidationCredentials() {
        return idpCertificateCredential;
    }

    @Override
    public boolean hasSigningCredential() {
        return signingCredential != null;
    }

    @Override
    public Credential getSigningCredential() {
        return signingCredential;
    }

    @Override
    public boolean hasDecryptionCredential() {
        return decryptionCredential != null;
    }

    @Override
    public Credential getDecryptionCredential() {
        return decryptionCredential;
    }
}
